<?php

namespace App\Actions\User;

use App\Actions\EventUser\Create as EventUserCreate;
use App\Actions\ModelHasRole\Create as ModelHasRoleCreate;
use App\Actions\User\Update as UserUpdate;
use App\Models\User;
use Filament\Facades\Filament;
use Filament\Notifications\Notification;
use Illuminate\Support\Facades\DB;

class Create
{
    public static function check($request)
    {
        $user = User::where('username', document_number_db($request['document_number']))
            ->orWhere('email', $request['email'])
            ->first();

        if ($user) {

            $data = [
                'password'         => document_number_db($request['document_number']),
                'access_until_day' => now()->addDays(15)->format('Y-m-d H:i:s'),
                'location_id'      => $request['location_id'],
                'collaborator_id'  => $request['collaborator_id'],
                'event_id'         => Filament::getTenant()->id,
            ];

            (new UserUpdate())->execute($user, $data);

            Notification::make()
                ->success()
                ->title('Usuario atualziado com sucesso!')
                ->icon('heroicon-m-user-plus')
                ->seconds(10)
                ->send();

            (new EventUserCreate())->execute($user);

            if ($request['role_id']) {

                $roles = [
                    'role_id' => $request['role_id'],
                    'user_id' => $user->id,
                ];

                (new ModelHasRoleCreate())->execute($roles);
            }

            return $user;
        }

        //        dd($request);
        if (! $user) {

            $data = [
                'name'             => $request['name'],
                'email'            => $request['email'],
                'username'         => document_number_db($request['document_number']),
                'password'         => document_number_db($request['document_number']),
                'access_until_day' => now()->addDays(15)->format('Y-m-d H:i:s'),
                'location_id'      => $request['location_id'],
                'collaborator_id'  => $request['collaborator_id'],
                'event_id'         => Filament::getTenant()->id,
            ];

            $user = self::execute($data);

            Notification::make()
                ->success()
                ->title('Usuario Cadastrado com sucesso!')
                ->icon('heroicon-m-user-plus')
                ->seconds(1)
                ->send();

            (new EventUserCreate())->execute($user);

            if ($request['role_id']) {

                $roles = [
                    'role_id' => $request['role_id'],
                    'user_id' => $user->id,
                ];

                (new ModelHasRoleCreate())->execute($roles);
            }

            return true;
        }
    }

    public static function execute($request)
    {
        return DB::transaction(function () use ($request) {

            return User::create($request);

        });
    }
}
