<?php

declare(strict_types = 1);

namespace App\Filament\Forms\Components;

use Filament\Forms\Components\Actions\Action;
use Filament\Forms\Components\Component;
use Filament\Forms\Components\TextInput;
use Filament\Forms\Set;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Http;
use Illuminate\Validation\ValidationException;
use Livewire\Component as Livewire;

class ZipCode extends TextInput
{
    public function viaCep(
        string $errorMessage = 'CEP inválido.',
        array $setFields = []
    ): static {
        $viaCepRequest = function (
            $state,
            $livewire,
            $set,
            $component,
            string $errorMessage,
            array $setFields
        ) {
            $livewire->validateOnly($component->getKey());

            $request = Http::withoutVerifying()->get("https://viacep.com.br/ws/$state/json/")->json();

            foreach ($setFields as $key => $value) {

                //                Cidade buscar no banco de dados e validar de acorodo o codigo do ibge
                if ($key === 'city_id') {
                    $city = \App\Models\City::where('ibge_code', $request['ibge'] ?? null)->first();

                    if (blank($city)) {
                        throw ValidationException::withMessages([$component->getKey() => $errorMessage]);
                    }
                    $set($key, $city->id);

                    continue;
                }

                $set($key, $request[$value] ?? null);
            }

            if (Arr::has($request, 'erro')) {
                throw ValidationException::withMessages([$component->getKey() => $errorMessage]);
            }

            $livewire->dispatch('cep');
        };
        $this
            ->mask('99999-999')
            ->maxLength(10)
            ->label('CEP')
            ->placeholder('Informe o CEP')
            ->suffixAction(
                Action::make('search-actions')
                    ->label('Buscar CEP')
                    ->icon('heroicon-o-magnifying-glass')
                    ->action(
                        function ($state, Livewire $livewire, Set $set, Component $component) use ($viaCepRequest, $errorMessage, $setFields) {
                            if (!blank($state)) {
                                $viaCepRequest($state, $livewire, $set, $component, $errorMessage, $setFields);
                            }
                        }
                    )
            );

        return $this;
    }
}
