<?php

namespace App\Filament\Pages;

use Filament\Pages\Page;
use setasign\Fpdi\Fpdi;
use Carbon\Carbon;

class SignPdfPage extends Page
{
    protected static ?string $navigationIcon = 'heroicon-o-document';

    protected static string $view = 'filament.pages.sign-pdf-page';

    public function signPdf()
    {
        // Caminhos para o certificado e chave privada em formato PEM
        $certFile = storage_path('app/COMBINATO1006385195.pem');
        $keyFile = storage_path('app/COMBINATO1006385195_privada.pem');
        $password = 'apoio'; // Se houver senha

        // Verifica se os arquivos existem
        if (!file_exists($certFile) || !file_exists($keyFile)) {
            session()->flash('error', 'Certificado ou chave privada não encontrados');
            return;
        }

        // Função para extrair informações do certificado
        $certInfo = $this->getCertInfo($certFile);

        // Carregar o PDF que será assinado
        $pdf = new Fpdi();
        $pdf->AddPage();
        $pdf->setSourceFile(storage_path('app/documento.pdf')); // PDF existente
        $tplIdx = $pdf->importPage(1);
        $pdf->useTemplate($tplIdx, 10, 10, 200);

        // Definir a fonte para evitar o erro "No font has been set"
        $pdf->SetFont('Arial', 'B', 8);

        // Informações de assinatura
        $protocolo = uniqid(); // Protocolo único
        $dataHora = Carbon::now()->format('d/m/Y H:i:s'); // Data e hora atual

        // Adicionar informações ao PDF
        $pdf->SetXY(10, 10); // Ajustar a posição para onde os dados serão exibidos
        $pdf->Cell(0, 8, "Assinado Digitalmente", 0, 1);
        $pdf->Cell(0, 8, "Nome: " . $certInfo['nome'], 0, 1);
        $pdf->Cell(0, 8, "Protocolo: $protocolo", 0, 1);
        $pdf->Cell(0, 8, "Data e Hora: $dataHora", 0, 1);
        $pdf->Cell(0, 8, "Emitente: " . $certInfo['emitente'], 0, 1);
//        $pdf->Cell(0, 10, "Validade: " . $certInfo['validade_inicial'] . " até " . $certInfo['validade_final'], 0, 1);
//        $pdf->Cell(0, 10, "Email: " . $certInfo['email'], 0, 1);

        // Extrair chave privada
        $pkeyid = openssl_pkey_get_private(file_get_contents($keyFile), $password);

        // Ler o certificado
        $cert = file_get_contents($certFile);

        // Assinar o documento
        openssl_sign($pdf->Output('S'), $cert, $pkeyid, OPENSSL_ALGO_SHA256);

        // Salvar o PDF assinado
        $outputFile = storage_path('app/documento-assinado.pdf');
        $pdf->Output($outputFile, 'F');

        // Libera a chave privada
        openssl_free_key($pkeyid);

        session()->flash('success', 'PDF assinado com sucesso!');
        return response()->download($outputFile);
    }

    // Função para extrair informações do certificado
    private function getCertInfo($certFile)
    {
        // Carregar o certificado
        $certContent = file_get_contents($certFile);

        // Extrair informações do certificado
        $certData = openssl_x509_parse($certContent);
ds($certData);
        if ($certData === false) {
            throw new \Exception("Não foi possível ler o certificado.");
        }

        return [
            'nome' => $certData['subject']['CN'] ?? 'Nome não encontrado',
            'emitente' => $certData['issuer']['CN'] ?? 'Emitente não encontrado',
            'validade_inicial' => date('d/m/Y', $certData['validFrom_time_t'] ?? time()),
            'validade_final' => date('d/m/Y', $certData['validTo_time_t'] ?? time()),
            'email' => $certData['subject']['emailAddress'] ?? 'Email não encontrado',
        ];
    }
}
