<?php

namespace App\Filament\Pages;

use App\Models\Term as ModelTerm;
use Filament\Forms\Components\RichEditor;
use Filament\Forms\Components\Section;
use Filament\Forms\Concerns\InteractsWithForms;
use Filament\Forms\Contracts\HasForms;
use Filament\Forms\Form;
use Filament\Notifications\Notification;
use Filament\Pages\Page;
use FilamentTiptapEditor\TiptapEditor;
use FilamentTiptapEditor\Enums\TiptapOutput;

class Term extends Page
{
    use InteractsWithForms;

    protected static ?string $navigationIcon = 'phosphor-text-align-left-duotone';

    protected static ?string $navigationGroup = 'Cadastros';

    protected static ?string $navigationLabel = 'Termo';

    protected static bool $isScopedToTenant = false;

    protected static string $view = 'filament.pages.term';

    public $id;

    public $text;

    public function mount()
    {
        $term = ModelTerm::find(1);

        if ($term) {
            $this->text = $term->text;
        }
    }

    public function submit()
    {

        $this->validate();

        ModelTerm::where('id', 1)->update([
            'text' => $this->text,
        ]);

        Notification::make()
            ->success()
            ->title('Termo Atualziado')
            ->body('O termo foi atualizado com sucesso.')
        ->send();

    }

    public function form(Form $form): Form
    {
        return $form
            ->schema([
                Section::make()
                    ->columns(6)
                    ->schema([
                TiptapEditor::make('text')
//                    ->gridLayouts([
//                        'two-columns',
//                        'three-columns',
//                        'four-columns',
//                        'five-columns',
//                        'fixed-two-columns',
//                        'fixed-three-columns',
//                        'fixed-four-columns',
//                        'fixed-five-columns',
//                        'asymmetric-left-thirds',
//                        'asymmetric-right-thirds',
//                        'asymmetric-left-fourths',
//                        'asymmetric-right-fourths',
//                    ])
//                    ->profile(['default|simple|minimal|none|custom'])
//                    ->tools([]) // individual tools to use in the editor, overwrites profile
//                    ->disk('string') // optional, defaults to config setting
//                    ->directory('string or Closure returning a string') // optional, defaults to config setting
//                    ->acceptedFileTypes(['array of file types']) // optional, defaults to config setting
//                    ->maxSize('integer in KB') // optional, defaults to config setting
//                    ->output(TiptapOutput::Html) // optional, change the format for saved data, default is html
                    ->maxContentWidth('5xl')
                    ->output(TiptapOutput::Json)
                    ->showMergeTagsInBlocksPanel(true)
                    ->required()

//                        RichEditor::make('text')
//                            ->toolbarButtons([
//                                'attachFiles',
//                                'blockquote',
//                                'bold',
//                                'bulletList',
//                                'codeBlock',
//                                'h2',
//                                'h3',
//                                'italic',
//                                'link',
//                                'orderedList',
//                                'redo',
//                                'strike',
//                                'underline',
//                                'undo',
//                            ])
//                            ->label('')
                            ->placeholder('Informe a condição')
//                            ->required()
                            ->columnSpanFull(),
                    ]),
            ]);
    }
}
