<?php

namespace App\Filament\Resources\CompanyResource\Pages;

use App\Filament\Resources\CompanyResource;
use App\Services\CertifiedService;
use App\Traits\RedirectHome;
use Filament\Actions;
use Filament\Notifications\Notification;
use Filament\Resources\Pages\EditRecord;

class EditCompany extends EditRecord
{
    use RedirectHome;

    protected static string $resource = CompanyResource::class;

    protected function getHeaderActions(): array
    {
        return [
            Actions\ViewAction::make(),
            Actions\DeleteAction::make(),
            Actions\ForceDeleteAction::make(),
            Actions\RestoreAction::make(),
        ];
    }

    protected function mutateFormDataBeforeSave(array $data): array
    {
        $certificadoService = new CertifiedService;
        $validationResult   = $certificadoService->validarCertificado($data);

        if (! $validationResult['success']) {
            Notification::make()
                ->title('Erro de Validação')
                ->body($validationResult['message'])
                ->danger()
                ->send();

            $this->halt();
        }

        $data['certified_expiration_date'] = $validationResult['data']['expiration_date'];
        $data['slug']                      = document_db($data['document_number']);

        return $data;
    }

    protected function afterSave()
    {
        $certificadoService = new CertifiedService;

        $this->processCertificateConversion(
            $certificadoService,
            'convertPEM',
            'certified_pem'
        );

        $this->processCertificateConversion(
            $certificadoService,
            'convertPrivate',
            'certified_private'
        );
    }

    private function processCertificateConversion(CertifiedService $service, string $method, string $field)
    {
        $result = $service->$method($this->record->toArray());

        $this->record->update([
            $field => $result['file'],
        ]);

        if (! $result['success']) {
            Notification::make()
                ->title('Erro de Validação')
                ->body($result['message'])
                ->danger()
                ->send();

            $this->halt();
        }
    }

}
