<?php
namespace App\Filament\Resources\CompanyResource\Tables;

use App\Models\Company;
use App\Models\Stock;
use Filament\Tables\Actions\ActionGroup;
use Filament\Actions\DeleteAction;
use Filament\Tables\Actions\EditAction;
use Filament\Notifications\Notification;
use Filament\Tables\Actions\Action;
use Filament\Tables\Actions\BulkActionGroup;
use Filament\Tables\Actions\DeleteBulkAction;
use Filament\Tables\Actions\ForceDeleteBulkAction;
use Filament\Tables\Actions\RestoreBulkAction;
use Filament\Tables\Actions\ViewAction;
use Filament\Tables\Columns\IconColumn;
use Filament\Tables\Columns\TextColumn;
use Filament\Tables\Filters\TrashedFilter;
use Filament\Tables\Table;

class Columns
{
    public static function make(Table $table): Table
    {
        return $table->columns([
            TextColumn::make('document_number')
                ->label('CPF/CNPJ')
                ->sortable()
                ->searchable(),
            TextColumn::make('name')
                ->label('Razão Social')
                ->sortable()
                ->searchable(),
            TextColumn::make('fantasy_name')
                ->label('Nome fantasia')
                ->sortable()
                ->searchable(),
            TextColumn::make('email')
                ->label('E-mail')
                ->placeholder('-')
                ->toggleable(isToggledHiddenByDefault: true)
                ->searchable(),
            TextColumn::make('phone_number')
                ->label('Telefone')
                ->placeholder('-')
                ->toggleable(isToggledHiddenByDefault: true)
                ->searchable(),
            TextColumn::make('mobile_number')
                ->label('Celular')
                ->placeholder('-')
                ->searchable(),
            IconColumn::make('is_active')
                ->label('Status')
                ->alignCenter()
                ->boolean(),
            TextColumn::make('created_at')
                ->label('Criado em')
                ->dateTime()
                ->sortable()
                ->toggleable(isToggledHiddenByDefault: true),
            TextColumn::make('updated_at')
                ->label('Atualizado em')
                ->dateTime()
                ->sortable()
                ->toggleable(isToggledHiddenByDefault: true),
            TextColumn::make('deleted_at')
                ->label('Excluído em')
                ->dateTime()
                ->sortable()
                ->toggleable(isToggledHiddenByDefault: true),
        ]) ->emptyStateHeading('Empresa não encontrados!')
            ->emptyStateDescription('Para adicionar empresa clique no botão abaixo.')
            ->filters([
                TrashedFilter::make(),
            ])
            ->actions([
                ViewAction::make(),
                    ActionGroup::make([
                    Action::make('toggle_active')
                        ->action(fn (Company $record) => $record->update(['is_active' => $record->is_active ? 0 : 1]))
                        ->label(fn (Company $record) => $record->is_active ? 'Desativar' : 'Ativar')
                        ->icon(fn (Company $record) => $record->is_active ? 'heroicon-o-x-circle' : 'heroicon-o-check-circle')
                        ->color(fn (Company $record) => $record->is_active ? 'danger' : 'success'),
                    EditAction::make(),
                    DeleteAction::make()->successNotification(
                        Notification::make()
                            ->success()
                            ->title('Empresa excluído!')
                            ->body('Empresa foi excluído com sucesso.'),
                    ),
                ])->iconButton()
                ->tooltip('Ações')
                ->color('gray'),
            ])
            ->bulkActions([
                BulkActionGroup::make([
                    DeleteBulkAction::make(),
                    ForceDeleteBulkAction::make(),
                    RestoreBulkAction::make(),
                ]),
            ]);
    }
}

