<?php

namespace App\Filament\Resources;

use App\Filament\Resources\UserResource\Pages;
use App\Models\Collaborator;
use App\Models\Company;
use App\Models\Location;
use App\Models\Patient;
use App\Models\User;
use BezhanSalleh\FilamentShield\Contracts\HasShieldPermissions;
use Filament\Forms;
use Filament\Forms\Components\Grid;
use Filament\Forms\Components\Section;
use Filament\Forms\Form;
use Filament\Forms\Get;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Filters\SelectFilter;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use STS\FilamentImpersonate\Tables\Actions\Impersonate;
use Rmsramos\Activitylog\RelationManagers\ActivitylogRelationManager;
use Illuminate\Support\Facades\Hash;

class UserResource extends Resource implements HasShieldPermissions
{
    protected static ?string $model = User::class;

    protected static ?string $navigationGroup = 'Sistema';

    protected static ?string $navigationIcon = 'phosphor-user-duotone';

    protected static ?string $pluralLabel = 'Usuários';

    protected static ?string $modelLabel = 'Usuário';

    protected static ?string $inverseRelationship = 'section';

    protected static bool $isScopedToTenant = false;

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Section::make('Informações Pessoais')
                ->schema([
                    Grid::make([])->schema([
                        Grid::make()
                            ->columns(3)
                            ->schema([
                        Forms\Components\TextInput::make('name')
                            ->label('Nome')
                            ->placeholder('Nome do usuário')
                            ->required()
                            ->columnSpan(2)
                            ->maxLength(255),
                                Forms\Components\TextInput::make('nickname')
                                    ->label('Conhecido por')
                                    ->placeholder('Informe como o usuário é conhecido')
                                    ->required()
                                    ->columnSpan(1)
                                    ->maxLength(50),
                        Forms\Components\TextInput::make('email')
                            ->label('Email')
                            ->placeholder('Email do usuário')
                            ->columnSpanFull()
                            ->email()
                            ->unique(ignoreRecord: true)
                            ->required()
                            ->maxLength(255),
                            ]),
                    ])->columnSpanFull(),
                    Grid::make()->schema([

                    Forms\Components\TextInput::make('username')
                        ->label('Login')
                        ->placeholder('Nome do usuário')
                        ->required()
                        ->unique(ignoreRecord: true)
                        ->columnSpanFull()
                        ->maxLength(50),
                    Forms\Components\TextInput::make('password')
                        ->label('Senha')
                        ->placeholder('Senha do usuário')
                        ->password()
                        ->revealable()
                        ->minLength(8)
                        ->required(fn(string $operation): bool => $operation === 'create')
                        ->autocomplete(false)
                        ->confirmed()
                        ->dehydrated(fn(?string $state): bool => filled($state))
                        ->maxLength(50),
                    Forms\Components\TextInput::make('password_confirmation')
                        ->label('Confirmação de Senha')
                        ->placeholder('Senha do usuário')
                        ->password()
                        ->requiredWith('password')
                        ->dehydrated(false)
                        ->minLength(8)
                        ->autocomplete(false)
                        ->maxLength(50),
                    ]),
                    Forms\Components\Select::make('roles')
                        ->label('Grupos de Acesso')
                        ->multiple()
                        ->relationship('roles', 'name', fn (Builder $query) => auth()->user()->hasRole('Developer') ? null : $query->where(
                            'name',
                            '!=',
                            'Developer'
                        ))
                        ->preload()
                        ->required()
                        ->columnSpanFull(),
                ])->columnSpan(2)->columns(3),
                Section::make('Informações Pessoais')
                    ->schema([
                        Forms\Components\FileUpload::make('avatar_url')
                            ->label('Avatar')
                            ->avatar()
                            ->visibility('private')
                            ->imageEditor()
                            ->image(),
                        Forms\Components\DatePicker::make('access_until_day')
                            ->label('Acesso até')
                            ->default(now()->addDay(10))
                            ->required(),
                        Forms\Components\Toggle::make('is_active')
                            ->label('Status')
                            ->inline(false)
                            ->default(true)
                            ->columnSpanFull()
                            ->required(),
                    ])->columnSpan(1)->columns(1),
                Section::make('Informações da Empresa')
                ->schema([
//                    Forms\Components\Select::make('location_id')
//                        ->label('Localidade')
//                        ->relationship('location', 'name')
//                        ->getOptionLabelFromRecordUsing(fn (Location $user): string => "{$user->location_name} - {$user->name}")
//                        ->columnSpanFull()
//                        ->searchable()
//                        ->required(),
//                    Forms\Components\Select::make('collaborator_id')
//                        ->label('Colaborador')
//                        ->options(function () {
//                            return Collaborator::all()->mapWithKeys(function ($item) {
//                                return [$item->id => $item->name . ' | CPF: ' . $item->document_number];
//                            });
//                        })
//                        ->columnSpanFull()
//                        ->searchable()
//                        ->required(),
                    Forms\Components\Select::make('companies')
                        ->label('Empresas')
                        ->multiple()
                        ->relationship('companies', 'name')
//                        ->getOptionLabelFromRecordUsing(fn (Evento $role): string => "{$role->fantasy_name} ({$role->document_number})")
                        ->required()
                        ->preload()
                        ->columnSpanFull(),
                ])->columns(9),
            ])->columns(3);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->paginated([10, 25, 50, 100])
            ->columns([
                Tables\Columns\ImageColumn::make('avatar_url')
                    ->label('Avatar')
                    ->defaultImageUrl(url('/images/placeholder.png'))
                    ->circular(),
                Tables\Columns\TextColumn::make('name')
                    ->label('Nome')
                    ->description(fn(User $user): string => $user->nickname)
                    ->searchable()
                    ->sortable(),
                Tables\Columns\TextColumn::make('email')
                    ->label('E-mail')
                    ->copyable()
                    ->copyableState(fn (string $state): string => "{$state}")
                    ->searchable()
                    ->sortable(),
                Tables\Columns\TextColumn::make('username')
                    ->label('Login')
                    ->copyable()
                    ->copyableState(fn (string $state): string => "{$state}")
                    ->searchable()
                    ->sortable(),
                Tables\Columns\TextColumn::make('roles.name')
                    ->label('Grupo de Acesso')
                    ->searchable()
                    ->sortable(),
                Tables\Columns\TextColumn::make('access_until_day')
                    ->label('Acesso até')
                    ->color(fn(User $user): string => $user->access_until_day < now()->format('Y-m-d') ? 'danger' : 'primary')
                    ->alignCenter()
                    ->date('d/m/Y'),
                Tables\Columns\TextColumn::make('access_number')
                    ->label('Acessos')
                    ->alignCenter()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\IconColumn::make('is_active')
                    ->label('Status')
                    ->alignCenter()
                    ->boolean(),
                Tables\Columns\TextColumn::make('last_login_at')
                    ->label('Último Acesso')
                    ->dateTime()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('created_at')
                    ->label('Data de Cadastro')
                    ->dateTime()
                    ->toggleable(isToggledHiddenByDefault: true)
                    ->sortable(),
                Tables\Columns\TextColumn::make('updated_at')
                    ->label('Data de Atualização')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->emptyStateHeading('Usuários não encontrados!')
            ->emptyStateDescription('Para adicionar usuários clique no botão abaixo.')
            ->emptyStateActions([
                Tables\Actions\CreateAction::make(),
            ])
            ->filters([
                Tables\Filters\TrashedFilter::make(),
                SelectFilter::make('status')
                ->options([
                    1 => 'Ativos',
                    0 => 'Inativos',
                ]),
                SelectFilter::make('roles')
                    ->label('Grupo de acessos')
                    ->relationship('roles', 'name')
                    ->multiple()
                    ->searchable()
                    ->preload(),
            ])
            ->actions([
                Tables\Actions\ViewAction::make(),
                Tables\Actions\EditAction::make(),
                Impersonate::make('impersonate')
                    ->label(__('Impersonate'))
                    ->icon('phosphor-detective-duotone'),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                    Tables\Actions\ForceDeleteBulkAction::make(),
                    Tables\Actions\RestoreBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [

        ];
    }

    public static function getPages(): array
    {
        return [
            'index'  => Pages\ListUsers::route('/'),
            'create' => Pages\CreateUser::route('/create'),
            'view'   => Pages\ViewUser::route('/{record}'),
            'edit'   => Pages\EditUser::route('/{record}/edit'),
        ];
    }

    public static function getEloquentQuery(): Builder
    {
        return auth()->user()->hasRole('Developer')
            ? parent::getEloquentQuery()
            : parent::getEloquentQuery()->whereHas('roles', function ($query) {
                $query->where('name', '!=', 'Developer');
            });
    }

    public static function getPermissionPrefixes(): array
    {
        return [
            'view_any',
            'view',
            'create',
            'update',
            'delete',
            'restore',
        ];
    }
}
