<?php

namespace App\Filament\Widgets;

use App\Models\LoanItem;
use App\Models\LoanItemLow;
use Carbon\Carbon;
use Filament\Widgets\ChartWidget;
use Filament\Widgets\Concerns\InteractsWithPageFilters;
use Illuminate\Support\Facades\DB;

class PaymentsReceiptsChart extends ChartWidget
{
    use InteractsWithPageFilters;

    protected static ?string $heading = 'Valores a Receber x Pagamentos (Mês)';

    protected int|string|array $columnSpan = 'full';

    protected static ?int $sort = 1;

    protected static ?string $maxHeight = '300px';

    protected function getType(): string
    {
        return 'bar';
    }

    protected function getData(): array
    {
        // Verificar se o filtro startDate está definido e é válido
        $startDate = $this->filters['startDate'] ?? now();

        // Obter o mês e ano corrente
        $currentMonth = Carbon::parse($startDate)->month;
        $currentYear  = Carbon::parse($startDate)->year;

        // Query usando Eloquent para pegar os valores do mês corrente
        $loanItems = LoanItem::selectRaw('DAY(due_at) as day, SUM(money) as total_money')
            ->whereMonth('due_at', $currentMonth)
            ->whereYear('due_at', $currentYear)
            ->groupBy(DB::raw('DAY(due_at)'))
            ->orderBy('day')
            ->get();

        // Query usando Eloquent para pegar os valores pagos do mês corrente
        $paidItems = LoanItemLow::selectRaw('DAY(paid_at) as day, SUM(paid_money) as total_paid')
            ->whereNotNull('paid_at')
            ->whereMonth('paid_at', $currentMonth)
            ->whereYear('paid_at', $currentYear)
            ->groupBy(DB::raw('DAY(paid_at)'))
            ->orderBy('day')
            ->get();

        // Preparando os dados para o gráfico
        $daysInMonth = Carbon::parse($startDate)->daysInMonth;
        $labels      = range(1, $daysInMonth);
        $data        = array_fill(0, $daysInMonth, 0);
        $paidData    = array_fill(0, $daysInMonth, 0);

        foreach ($loanItems as $item) {
            $data[$item->day - 1] = $item->total_money;
        }

        foreach ($paidItems as $item) {
            $paidData[$item->day - 1] = $item->total_paid;
        }

        return [
            'datasets' => [
                [
                    'label'           => 'Valores a Pagar',
                    'data'            => $data,
                    'fill'            => 'bar',
                    'backgroundColor' => 'rgba(255, 99, 132)',
                    'borderColor'     => 'rgba(255, 99, 132)',
                ],
                [
                    'label'           => 'Valores Pagos',
                    'data'            => $paidData,
                    'fill'            => 'bar',
                    'backgroundColor' => 'rgba(144, 238, 144)',
                    'borderColor'     => 'rgba(144, 238, 144)',
                ],
            ],
            'borderWidth' => 0,
            'labels'      => $labels,  // Labels agora são todos os dias do mês
        ];
    }
}
