<?php

namespace App\Filament\Widgets;

use App\Models\LoanItem;
use App\Models\LoanItemLow;
use Carbon\Carbon;
use Filament\Widgets\Concerns\InteractsWithPageFilters;
use Filament\Widgets\StatsOverviewWidget as BaseWidget;
use Filament\Widgets\StatsOverviewWidget\Stat;

class StatsOverviewWidget extends BaseWidget
{
    use InteractsWithPageFilters;

    protected static ?int $sort = 0;



protected function getStats(): array
{
    // Definir a data de início e fim com base nos filtros
    $startDate = $this->filters['startDate'] ?? null ? Carbon::parse($this->filters['startDate']) : null;
    $endDate = $this->filters['endDate'] ?? null ? Carbon::parse($this->filters['endDate'])->endOfDay() : now()->endOfDay();

    // Consultando a tabela loan_items para calcular os valores
    $loanItemsQuery = LoanItem::query();

    if ($startDate) {
        $loanItemsQuery->where('due_at', '>=', $startDate);
    }

    $loanItemsQuery->where('due_at', '<=', $endDate);

    $loanItems = $loanItemsQuery->get();

    // Calculando os valores
    $totalDebt     = $loanItems->sum('money');
    $totalPaid     = LoanItemLow::whereBetween('paid_at', [$startDate, $endDate])->sum('paid_money');
    $remainingDebt = $totalDebt - $totalPaid;
    $clientCount   = $loanItems->groupBy('registry_id')->count();

    // Gráfico de valores a receber por dia
    $debtChart = $loanItems->groupBy(function ($item) {
        return Carbon::parse($item->due_at)->format('Y-m-d'); // Agrupa por dia
    })->map->sum('money')->values()->toArray();

    // Gráfico de valores pagos por dia
    $paidChart = LoanItemLow::whereBetween('paid_at', [$startDate, $endDate])
        ->get()
        ->groupBy(function ($item) {
            return Carbon::parse($item->paid_at)->format('Y-m-d'); // Agrupa por dia
        })->map->sum('paid_money')->values()->toArray();

    return [
        Stat::make('Valores a Receber', 'R$ ' . money_view($totalDebt))
            ->description('Valores a receber por período')
            ->descriptionIcon('heroicon-m-arrow-trending-up')
            ->chart($debtChart) // Gráfico baseado nos valores a receber por dia
            ->color('danger'),

        Stat::make('Valores Pagos', 'R$ ' . money_view($totalPaid))
            ->description('Pagamentos realizados por período')
            ->descriptionIcon('heroicon-m-arrow-trending-up')
            ->chart($paidChart) // Gráfico baseado nos valores pagos por dia
            ->color('success'),

        Stat::make('Clientes', left_zero($clientCount,2))
            ->description('Quantidade de Clientes')
            ->descriptionIcon('heroicon-m-user-group')
            ->chart([0, $clientCount]) // Exemplo de gráfico de clientes (pode ser ajustado)
            ->color('info'),
    ];
}
}
