<?php

use Carbon\Carbon;
use Filament\Facades\Filament;

if (! function_exists('date_db')) {
    /**
     * Convert date for DB format (YYYY-MM-DD).
     *
     * @param  string  $date
     * @return string
     */
    function date_db($date)
    {
        return implode('-', array_reverse(explode('/', $date)));
    }
}

if (! function_exists('date_view')) {
    function date_view($date, $showTime = true) {
        try {
            $carbonDate = Carbon::parse($date);

            if ($showTime && strpos($date, ' ') !== false) {
                return $carbonDate->format('d/m/Y H:i:s');
            }

            return $carbonDate->format('d/m/Y');
        } catch (\Exception $e) {
            return $date;
        }
    }
}

if (! function_exists('numberToText')) {

    /**
     * Formata string colocando zeros à esquerda.
     *
     * @param  string  $value
     * @param  int  $qty
     * @return string
     */
    function numberToText($value, $uppercase = 0)
    {
        if (strpos($value, ',') > 0) {
            $value = str_replace('.', '', $value);
            $value = str_replace(',', '.', $value);
        }

        $singular = ['centavo', 'real', 'mil', 'milhão', 'bilhão', 'trilhão', 'quatrilhão'];
        $plural   = ['centavos', 'reais', 'mil', 'milhões', 'bilhões', 'trilhões', 'quatrilhões'];

        $c   = ['', 'cem', 'duzentos', 'trezentos', 'quatrocentos', 'quinhentos', 'seiscentos', 'setecentos', 'oitocentos', 'novecentos'];
        $d   = ['', 'dez', 'vinte', 'trinta', 'quarenta', 'cinquenta', 'sessenta', 'setenta', 'oitenta', 'noventa'];
        $d10 = ['dez', 'onze', 'doze', 'treze', 'quatorze', 'quinze', 'dezesseis', 'dezesete', 'dezoito', 'dezenove'];
        $u   = ['', 'um', 'dois', 'três', 'quatro', 'cinco', 'seis', 'sete', 'oito', 'nove'];

        $z = 0;

        $value   = number_format($value, 2, '.', '.');
        $integer = explode('.', $value);
        $cont    = count($integer);

        for ($i = 0; $i < $cont; $i++) {
            for ($ii = strlen($integer[$i]); $ii < 3; $ii++) {
                $integer[$i] = '0' . $integer[$i];
            }
        }

        $fim = $cont - ($integer[$cont - 1] > 0 ? 1 : 2);
        $rt  = '';

        for ($i = 0; $i < $cont; $i++) {
            $value = $integer[$i];
            $rc    = (($value > 100) && ($value < 200)) ? 'cento' : $c[$value[0]];
            $rd    = ($value[1] < 2) ? '' : $d[$value[1]];
            $ru    = ($value > 0) ? (($value[1] == 1) ? $d10[$value[2]] : $u[$value[2]]) : '';

            $r = $rc . (($rc && ($rd || $ru)) ? ' e ' : '') . $rd . (($rd &&
                    $ru) ? ' e ' : '') . $ru;
            $t = $cont - 1 - $i;
            $r .= $r ? ' ' . ($value > 1 ? $plural[$t] : $singular[$t]) : '';

            if ($value == '000'
            ) {
                $z++;
            } elseif ($z > 0) {
                $z--;
            }

            if (($t == 1) && ($z > 0) && ($integer[0] > 0)) {
                $r .= (($z > 1) ? ' de ' : '') . $plural[$t];
            }

            if ($r) {
                $rt = $rt . ((($i > 0) && ($i <= $fim) &&
                        ($integer[0] > 0) && ($z < 1)) ? (($i < $fim) ? ', ' : ' e ') : ' ') . $r;
            }
        }

        return trim($rt ? $rt : 'zero');
    }
}

if (! function_exists('competence')) {

    /**
     * Formata string colocando zeros à esquerda.
     *
     * @param  string  $value
     * @param  int  $qty
     * @return string
     */
    function competence($date)
    {
        $meses = [
            1  => 'Janeiro',
            2  => 'Fevereiro',
            3  => 'Março',
            4  => 'Abril',
            5  => 'Maio',
            6  => 'Junho',
            7  => 'Julho',
            8  => 'Agosto',
            9  => 'Setembro',
            10 => 'Outubro',
            11 => 'Novembro',
            12 => 'Dezembro',
        ];

        // Converte a data para um objeto DateTime
        $dateTime = new DateTime($date);

        // Obtém o número do mês
        $numeroMes = $dateTime->format('n');

        // Obtém o nome do mês com base no número
        $mesPorExtenso = $meses[$numeroMes];

        // Obtém o ano
        $ano = $dateTime->format('Y'); // 'Y' retorna o ano com 4 dígitos

        // Concatena o mês e o ano em uma string
        $resultado = $mesPorExtenso . '/' . $ano;

        return $resultado;

    }

    if (! function_exists('get_month')) {
        function get_month($month = null)
        {
            $month = (int) $month;

            $months = [
                1  => 'JANEIRO',
                2  => 'FEVEREIRO',
                3  => 'MARÇO',
                4  => 'ABRIL',
                5  => 'MAIO',
                6  => 'JUNHO',
                7  => 'JULHO',
                8  => 'AGOSTO',
                9  => 'SETEMBRO',
                10 => 'OUTUBRO',
                11 => 'NOVEMBRO',
                12 => 'DEZEMBRO',
            ];

            return ($month) ? $months[$month] : $months;
        }
    }

    if (! function_exists('day_week')) {
        function day_week($data)
        {
            setlocale(LC_TIME, 'pt_BR', 'pt_BR.utf-8', 'pt_BR.utf-8', 'portuguese');
            date_default_timezone_set('America/Sao_Paulo');

            $date = new DateTime($data);

            return strftime('%A', $date->getTimestamp());
        }
    }

    if (! function_exists('getUrlBal')) {
        function getUrlBal()
        {
            $url = 'https://example.com';

            return response()->json(['url' => $url]);
        }
    }

    if (! function_exists('getAge')) {
        function getAge($date = null)
        {
            return ($date) ? Carbon::parse($date)->age : '';
        }
    }

    if (! function_exists('getMonthName')) {
        function getMonthName($monthNumber)
        {
            $months = [
                '01' => 'Janeiro',
                '02' => 'Fevereiro',
                '03' => 'Março',
                '04' => 'Abril',
                '05' => 'Maio',
                '06' => 'Junho',
                '07' => 'Julho',
                '08' => 'Agosto',
                '09' => 'Setembro',
                '10' => 'Outubro',
                '11' => 'Novembro',
                '12' => 'Dezembro',
            ];

            return $months[$monthNumber] ?? 'Mês inválido';
        }
    }

    if (! function_exists('daysUntilDue')) {
        /**
         * Calculate the days until or since the due date.
         *
         * @param  mixed  $dueDate
         * @return int The number of days until (positive) or since (negative) the due date.
         */
        function daysUntilDue($dueDate): int
        {
            $now     = Carbon::now();
            $dueDate = Carbon::parse($dueDate);

            return $dueDate->diffInDays($now, false);
        }
    }

    if (! function_exists('addIntervalToDate')) {
        function addIntervalToDate($currentDate, $interval)
        {
            switch ($interval) {
                case 'daily':
                    do {
                        $currentDate->addDay();
                    } while ($currentDate->isWeekend());

                    break;
                case 'weekly':
                    do {
                        $currentDate->addWeek();
                    } while ($currentDate->isWeekend());

                    break;
                case 'fortnightly':
                    do {
                        $currentDate->addWeeks(2);
                    } while ($currentDate->isWeekend());

                    break;
                case 'monthly':
                    do {
                        $currentDate->addMonth();
                    } while ($currentDate->isWeekend());

                    break;
                case 'quarterly':
                    do {
                        $currentDate->addMonths(3);
                    } while ($currentDate->isWeekend());

                    break;
                case 'yearly':
                    do {
                        $currentDate->addYear();
                    } while ($currentDate->isWeekend());

                    break;
                default:
                    throw new InvalidArgumentException("Intervalo inválido: $interval");
            }
        }
    }

    if (! function_exists('local_now')) {
        function local_now(): \Illuminate\Support\Carbon
        {
            return now(config('app.local_timezone'));
        }
    }

    if (! function_exists('local_date')) {
        function local_date(\Illuminate\Support\Carbon|string|null $date = null, string $format = 'd/m/Y', bool $short = false): ?string
        {
            if (! $date) {
                return null;
            }

            if (! $date instanceof \Illuminate\Support\Carbon) {
                $date = \Illuminate\Support\Carbon::parse($date);
            }

            return $date
                ->timezone(config('app.local_timezone'))
                ->when(
                    fn (\Illuminate\Support\Carbon $carbon) => $short && $carbon->isCurrentYear(),
                    fn (\Illuminate\Support\Carbon $carbon) => $carbon->translatedFormat(str($format)->replaceMatches('/[\/\-]?\s?[Yy][\/\-]?/', '')),
                    fn (\Illuminate\Support\Carbon $carbon) => $carbon->translatedFormat($format)
                );
        }
    }

    if (! function_exists('local_time')) {
        function local_time(\Illuminate\Support\Carbon|string|null $time = null, string $format = 'H:i'): ?string
        {
            if (! $time) {
                return null;
            }

            if (! $time instanceof \Illuminate\Support\Carbon) {
                $time = \Illuminate\Support\Carbon::parse($time);
            }

            return $time
                ->timezone(config('app.local_timezone'))
                ->translatedFormat($format);
        }
    }

    if (! function_exists('local_datetime')) {
        function local_datetime(\Illuminate\Support\Carbon|string|null $datetime = null, string $format = 'd/m/Y H:i', bool $short = false): ?string
        {
            if (! $datetime) {
                return null;
            }

            if (! $datetime instanceof \Illuminate\Support\Carbon) {
                $datetime = \Illuminate\Support\Carbon::parse($datetime);
            }

            return $datetime
                ->timezone(config('app.local_timezone'))
                ->when(
                    fn (\Illuminate\Support\Carbon $carbon) => $short && $carbon->isCurrentYear(),
                    fn (\Illuminate\Support\Carbon $carbon) => $carbon->translatedFormat(str($format)->replaceMatches('/[\/\-]?\s?[Yy][\/\-]?/', '')),
                    fn (\Illuminate\Support\Carbon $carbon) => $carbon->translatedFormat($format)
                );
        }
    }

    if (! function_exists('array_remove')) {
        function array_remove(array &$arr, $key)
        {
            if (array_key_exists($key, $arr)) {
                $val = $arr[$key];
                unset($arr[$key]);

                return $val;
            }

            return null;
        }
    }

    if (! function_exists('html')) {
        function html(?string $html = null): ?\Illuminate\Support\HtmlString
        {
            if (! $html) {
                return null;
            }

            return new \Illuminate\Support\HtmlString($html);
        }
    }

    if (! function_exists('md')) {
        function md(?string $string = null): ?\Illuminate\Support\HtmlString
        {
            if (! $string) {
                return null;
            }

            return \Illuminate\Support\Str::of($string)->markdown()->toHtmlString();
        }
    }

    if (! function_exists('blade')) {
        function blade(?string $string = null, array $data = [], bool $deleteCachedView = false): ?string
        {
            if (! $string) {
                return null;
            }

            return \Illuminate\Support\Facades\Blade::render($string, $data, $deleteCachedView);
        }
    }

    if (! function_exists('enum_equals')) {
        function enum_equals(\BackedEnum|array $enum, \BackedEnum|string|int|null $value): bool
        {
            if (is_array($enum)) {
                return array_reduce($enum, fn (bool $carry, \BackedEnum $enum) => $carry || enum_equals($enum, $value), false);
            }

            if (! $value instanceof \BackedEnum) {
                return $enum::tryFrom($value) === $enum;
            }

            return $enum === $value;
        }
    }

    if (! function_exists('tenant')) {
        /**
         * @template TValue
         *
         * @param  class-string<TValue>  $class
         * @return TValue|mixed
         */
        function tenant(string $class, ?string $attribute = null): mixed
        {
            return once(function () use ($class, $attribute) {
                $tenant = \Filament\Facades\Filament::getTenant();

                if (! $tenant instanceof $class) {
                    return null;
                }

                if (is_null($attribute)) {
                    return $tenant;
                }

                return $tenant?->getAttribute($attribute) ?? null;
            });
        }
    }

    if (! function_exists('getTenant')) {
        /**
         * @template TValue
         *
         * @param  class-string<TValue>  $class
         * @return TValue|mixed
         */
        function getTenant($attribute = 'id'): mixed
        {
            return Filament::getTenant()->$attribute;
        }
    }

    if (! function_exists('css_classes')) {
        function css_classes($classes = []): string
        {
            return \Illuminate\Support\Arr::toCssClasses($classes);
        }
    }

    if (! function_exists('mask')) {
        /**
         * Applies mask in the value.
         */
        function mask(string $mask, $value): ?string
        {
            if (is_null($value)) {
                return null;
            }

            // Apply mask
            $value       = str_replace(' ', '', $value);
            $replacedStr = \Illuminate\Support\Str::replaceArray('#', str_split($value), $mask);

            // Get filled substring
            $posSymbol      = strpos($replacedStr, '#', strlen($value));
            $replacedStrLen = strlen($replacedStr);
            $length         = $posSymbol ? $replacedStrLen - ($replacedStrLen - $posSymbol) : $replacedStrLen;

            return substr($replacedStr, 0, $length);
        }
    }

}
