<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Symfony\Component\HttpFoundation\Response;

class BaseController extends Controller
{
    /**
     * Return default response.
     *
     * @param mixed $message
     * @param mixed $data
     * @param mixed $statusCode
     *
     * @return \Illuminate\Http\Response
     */
    protected function response($message, $data = [], $statusCode = Response::HTTP_OK)
    {
        $response = [
            'status'  => $statusCode,
            'message' => $message,
        ];

        if ($data) {
            $response['data'] = $data;
        }

        if ($statusCode >= 400) {
            $response['error'] = true;
        }

        return response()->json($response, $statusCode);
    }

    /**
     * Return error response.
     *
     * @param mixed $message
     * @param mixed $data
     * @param mixed $statusCode
     *
     * @return \Illuminate\Http\Response
     */
    protected function responseError($message, $data = [], $statusCode = Response::HTTP_INTERNAL_SERVER_ERROR)
    {
        return $this->response($message, $data, $statusCode);
    }
}
