<?php

namespace App\Models;

use App\Enums\ModelTypeCashierEnum;
use App\Enums\TypeCashierEnum;
use App\Models\Traits\Uuids;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Cashier extends Model
{
    use HasFactory;
    use Uuids;

    protected $fillable = [
        'uuid',
        'company_id',
        'model_type',
        'model_id',
        'payment_form_id',
        'account_plan_id',
        'date',
        'type',
        'money',
        'historic',
        'observation',
        'is_active',
    ];

    public function casts()
    {
        return [
            'date'       => 'datetime',
            'type'       => TypeCashierEnum::class,
            'status'     => 'boolean',
            'model_type' => ModelTypeCashierEnum::class,
        ];
    }

    public function paymentForm()
    {
        return $this->belongsTo(PaymentForm::class);
    }

    public function paymentFormMovement()
    {
        return $this->belongsTo(PaymentForm::class)->where('is_cashier_movement_view', true);
    }

    public function accountPlan()
    {
        return $this->belongsTo(AccountPlan::class);
    }
}
