<?php

namespace App\Models;

use App\Casts\Document;
use App\Casts\ZipCode;
use App\Models\Traits\Uuids;
use Filament\Models\Contracts\HasName;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Company extends BaseModel implements HasName
{
    use Uuids;

    protected $fillable = [
        'company_id',
        'type_taxation',
        'name',
        'fantasy_name',
        'initial',
        'slug',
        'document_number',
        'state_registration',
        'municipal_registration',
        'zip_code',
        'address',
        'address_number',
        'neighborhood',
        'address_complement',
        'city_id',
        'mobile_number',
        'phone_number',
        'email',    
        'website',
        'responsible_name',
        'responsible_function',
        'certified',
        'certified_pem',
        'certified_private',
        'certified_password',
        'certified_expiration_date',
        'observation',
        'is_active',
    ];

    protected function casts(): array
    {
        return [
            'document_number' => Document::class,
            'zip_code'        => ZipCode::class,
            'status'          => 'boolean',
        ];
    }

    public function getFilamentName(): string
    {
        return "{$this->fantasy_name}";
    }

    public function setting()
    {
        return $this->hasOne(CompanySetting::class);
    }

    public function city()
    {
        return $this->belongsTo(City::class);
    }

    public function Registries(): HasMany
    {
        return $this->hasMany(Registry::class);
    }

    public function Files(): HasMany
    {
        return $this->hasMany(File::class);
    }


    public function members(): BelongsToMany
    {
        return $this->belongsToMany(User::class);
    }

}
