<?php

namespace App\Models;

use App\Enums\ExpirationTypeEnum;
use App\Models\Traits\Uuids;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Loan extends BaseModel
{
    use Uuids;
    use HasFactory;

    protected $fillable = [
        'company_id',
        'registry_id',
        'contract_id',
        'user_id',
        'money',
        'money_sum',
        'tax_money',
        'installments',
        'date_at',
        'due_first_at',
        'tax',
        'tax_day',
        'fine',
        'expiration_type',
        'signature',
        'is_active',
        'observation',
    ];

    public function cast()
    {
        return [
            'date_at'         => 'date',
            'due_first_at'    => 'date',
            'is_active'       => 'boolean',
            'expiration_type' => ExpirationTypeEnum::class,
        ];
    }

    public function getRouteKeyName(): string
    {
        return 'uuid';
    }

    public function company()
    {
        return $this->belongsTo(Company::class);
    }

    public function registry()
    {
        return $this->belongsTo(Registry::class);
    }

    public function contract()
    {
        return $this->belongsTo(Registry::class);
    }

    public function items()
    {
        return $this->hasMany(LoanItem::class);
    }
}
