<?php

namespace App\Models;

use App\Casts\Document;
use App\Casts\ZipCode;
use App\Models\Traits\Uuids;

class Registry extends BaseModel
{
    use Uuids;

    protected $fillable = [
        'uuid',
        'company_id',
        'document_number',
        'identity_document',
        'state_registration',
        'municipal_registration',
        'suframa',
        'antt',
        'contribuinte_icms',
        'responsible_name',
        'responsible_fantasy_name',
        'responsible_function',
        'name',
        'fantasy_name',
        'birthday',
        'zip_code',
        'address',
        'address_number',
        'neighborhood',
        'address_complement',
        'address_reference',
        'city_id',
        'mobile_number',
        'phone_number',
        'email',
        'email_nfe',
        'website',
        'observation',
        'avatar_url',
        'is_active',
    ];

    protected $casts = [
        'document_number' => Document::class,
        'zip_code' => ZipCode::class,
        'is_active' => 'boolean',
    ];

    public function city()
    {
        return $this->belongsTo(City::class);
    }

    public function company()
    {
        return $this->belongsTo(Company::class);
    }

    public function getAvatarUrlAttribute($value)
    {
        return $value ? asset('storage/' . $value) : null;
    }
}
