<?php

namespace App\Policies;

use App\Models\User;
use App\Models\ReceiptPayment;
use Illuminate\Auth\Access\HandlesAuthorization;

class ReceiptPaymentPolicy
{
    use HandlesAuthorization;

    /**
     * Determine whether the user can view any models.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function viewAny(User $user): bool
    {
        return $user->can('view_any_receipt::payment');
    }

    /**
     * Determine whether the user can view the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\ReceiptPayment  $receiptPayment
     * @return bool
     */
    public function view(User $user, ReceiptPayment $receiptPayment): bool
    {
        return $user->can('view_receipt::payment');
    }

    /**
     * Determine whether the user can create models.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function create(User $user): bool
    {
        return $user->can('create_receipt::payment');
    }

    /**
     * Determine whether the user can update the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\ReceiptPayment  $receiptPayment
     * @return bool
     */
    public function update(User $user, ReceiptPayment $receiptPayment): bool
    {
        return $user->can('update_receipt::payment');
    }

    /**
     * Determine whether the user can delete the model.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\ReceiptPayment  $receiptPayment
     * @return bool
     */
    public function delete(User $user, ReceiptPayment $receiptPayment): bool
    {
        return $user->can('delete_receipt::payment');
    }

    /**
     * Determine whether the user can bulk delete.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function deleteAny(User $user): bool
    {
        return $user->can('{{ DeleteAny }}');
    }

    /**
     * Determine whether the user can permanently delete.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\ReceiptPayment  $receiptPayment
     * @return bool
     */
    public function forceDelete(User $user, ReceiptPayment $receiptPayment): bool
    {
        return $user->can('{{ ForceDelete }}');
    }

    /**
     * Determine whether the user can permanently bulk delete.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function forceDeleteAny(User $user): bool
    {
        return $user->can('{{ ForceDeleteAny }}');
    }

    /**
     * Determine whether the user can restore.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\ReceiptPayment  $receiptPayment
     * @return bool
     */
    public function restore(User $user, ReceiptPayment $receiptPayment): bool
    {
        return $user->can('restore_receipt::payment');
    }

    /**
     * Determine whether the user can bulk restore.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function restoreAny(User $user): bool
    {
        return $user->can('{{ RestoreAny }}');
    }

    /**
     * Determine whether the user can replicate.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\ReceiptPayment  $receiptPayment
     * @return bool
     */
    public function replicate(User $user, ReceiptPayment $receiptPayment): bool
    {
        return $user->can('{{ Replicate }}');
    }

    /**
     * Determine whether the user can reorder.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function reorder(User $user): bool
    {
        return $user->can('{{ Reorder }}');
    }

    /**
     * Determine whether the user can reorder.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function pdf(User $user): bool
    {
        return $user->can('{{ Reorder }}');
    }

        /**
     * Determine whether the user can reorder.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function import(User $user): bool
    {
        return $user->can('{{ Reorder }}');
    }

          /**
     * Determine whether the user can reorder.
     *
     * @param  \App\Models\User  $user
     * @return bool
     */
    public function export(User $user): bool
    {
        return $user->can('{{ Reorder }}');
    }

}
