<?php

namespace App\Providers\Filament;

use App\Filament\Pages\Dashboard;
use App\Filament\Resources\AuditLogResource;
use App\Filament\Widgets\AccountWidget;
use App\Filament\Widgets\ReceiptsChart;
use App\Filament\Widgets\PaymentsReceiptsChart;
use App\Filament\Widgets\StatsOverviewWidget;
use App\Http\Middleware\ActionsTopBarLogoutMiddleware;
use App\Http\Middleware\ActionsTopBarMiddleware;
use App\Http\Middleware\RedirectNotActiveUser;
use App\Models\Company;
use BezhanSalleh\FilamentShield\FilamentShieldPlugin;
use CharrafiMed\GlobalSearchModal\GlobalSearchModalPlugin;
use DutchCodingCompany\FilamentDeveloperLogins\FilamentDeveloperLoginsPlugin;
use Filament\Enums\ThemeMode;
use Filament\Http\Middleware\Authenticate;
use Filament\Http\Middleware\DisableBladeIconComponents;
use Filament\Http\Middleware\DispatchServingFilamentEvent;
use Filament\Pages;
use Filament\Pages\Auth\Login;
use Filament\Panel;
use Filament\PanelProvider;
use Filament\Support\Colors\Color;
use Filament\Support\Enums\MaxWidth;
use Filament\Tables\Table;
use Filament\Widgets;
use Illuminate\Cookie\Middleware\AddQueuedCookiesToResponse;
use Illuminate\Cookie\Middleware\EncryptCookies;
use Illuminate\Foundation\Http\Middleware\VerifyCsrfToken;
use Illuminate\Routing\Middleware\SubstituteBindings;
use Illuminate\Session\Middleware\AuthenticateSession;
use Illuminate\Session\Middleware\StartSession;
use Illuminate\View\Middleware\ShareErrorsFromSession;
use Njxqlus\FilamentProgressbar\FilamentProgressbarPlugin;
use pxlrbt\FilamentSpotlight\SpotlightPlugin;
use Rmsramos\Activitylog\ActivitylogPlugin;

class AdminPanelProvider extends PanelProvider
{
    public function panel(Panel $panel): Panel
    {
        return $panel
            ->default()
            ->id('admin')
            ->path('admin')
            ->login(\App\Filament\Pages\Auth\Login::class)
            ->profile()
            ->spa(true)
            ->tenant(Company::class, ownershipRelationship: 'company', slugAttribute: 'slug')
            ->brandLogo(asset('images/logo-header.png'))
            ->darkModeBrandLogo(asset('images/logo-header-dark.png'))
            ->brandLogoHeight('2.1em')
            ->favicon(asset('images/favicon.png'))
            ->sidebarCollapsibleOnDesktop()
            ->brandName(fn() => auth()->check() ? 'Garantir' : 'Acesso ao Sistema')
            ->defaultThemeMode(ThemeMode::Light)
            ->maxContentWidth(MaxWidth::Full)
            ->navigationGroups([
                'Sistema',
                'Cadastros',
                'Operacional',
            ])
            ->colors([
                'primary' => Color::Sky,
                'gray' => Color::Slate,
            ])
            ->discoverResources(in: app_path('Filament/Resources'), for: 'App\\Filament\\Resources')
            ->discoverPages(in: app_path('Filament/Pages'), for: 'App\\Filament\\Pages')
            ->widgets([
                AccountWidget::class,
            ])
            ->pages([
                Dashboard::class,
            ])
            ->middleware([
                EncryptCookies::class,
                AddQueuedCookiesToResponse::class,
                StartSession::class,
                RedirectNotActiveUser::class,
                AuthenticateSession::class,
                ShareErrorsFromSession::class,
                VerifyCsrfToken::class,
                SubstituteBindings::class,
                DisableBladeIconComponents::class,
                DispatchServingFilamentEvent::class,
                ActionsTopBarLogoutMiddleware::class,
                ActionsTopBarMiddleware::class,
            ])
            ->authMiddleware([
                Authenticate::class,
            ])
            ->plugins([
                FilamentProgressbarPlugin::make()->color('#08285f'),
                ActivitylogPlugin::make()
                    ->resource(AuditLogResource::class)
                    ->label('Logs')
                    ->pluralLabel('Logs')
                    ->navigationIcon('phosphor-read-cv-logo-duotone')
                    ->navigationGroup('Sistema'),
                SpotlightPlugin::make(),
                GlobalSearchModalPlugin::make()
                    ->localStorageMaxItemsAllowed(10),
                FilamentShieldPlugin::make()
                    ->gridColumns([
                        'default' => 1,
                        'sm'      => 2,
                        'lg'      => 2,
                    ])
                    ->sectionColumnSpan(1)
                    ->checkboxListColumns([
                        'default' => 1,
                        'sm'      => 2,
                        'lg'      => 2,
                    ])
                    ->resourceCheckboxListColumns([
                        'default' => 1,
                        'sm'      => 2,
                    ]),
                FilamentDeveloperLoginsPlugin::make()

                    ->enabled()
                    ->users([
                        'Admin' => 'eu@lhonay.com',
//                        'User' => 'user@example.com',
                    ])
                    ->enabled(app()->environment('local'))
                    ->switchable(false)
            ])
            ->viteTheme('resources/css/filament/admin/theme.css')
            ->databaseNotifications()
            ->databaseNotificationsPolling('30s')
            ->bootUsing(function () {
                Table::configureUsing(fn ($table) => $table->paginationPageOptions([10, 25, 50, 100]));
            })
            ->unsavedChangesAlerts();

    }
}
