<?php

namespace App\Services;

use Exception;
use Symfony\Component\Process\Process;

class CertifiedService
{
    public function validarCertificado(array $data): array
    {
        $certificadoPfx      = storage_path('app/public/' . $data['certified']);
        $certificadoPassword = $data['certified_password'];

        $comandoValidacao = "openssl pkcs12 -in $certificadoPfx -nodes -password pass:$certificadoPassword -nocerts -out /dev/null";

        try {
            $processValidacao = Process::fromShellCommandline($comandoValidacao);
            $processValidacao->run();

            if (! $processValidacao->isSuccessful()) {
                return [
                    'success' => false,
                    'message' => 'Senha do certificado incorreta.',
                    'data'    => $processValidacao->getErrorOutput(),
                ];
            }

            // Comando para extrair todos os dados do certificado
            $comandoDados = "openssl pkcs12 -in $certificadoPfx -nodes -password pass:$certificadoPassword";
            $processDados = Process::fromShellCommandline($comandoDados);
            $processDados->run();

            if (! $processDados->isSuccessful()) {
                return [
                    'success' => false,
                    'message' => 'Erro ao extrair dados do certificado.',
                    'data'    => $processDados->getErrorOutput(),
                ];
            }

            // Extrair informações do certificado
            $certificadoInfo = openssl_x509_parse($processDados->getOutput());

            $expirationDate = date('Y-m-d H:i:s', $certificadoInfo['validTo_time_t']);
            $razaoSocial    = $certificadoInfo['subject']['O'] ?? 'N/A';
            $endereco       = $certificadoInfo['subject']['L'] ?? 'N/A';
            $cnpj           = $certificadoInfo['subject']['serialNumber'] ?? 'N/A';

            return [
                'success' => true,
                'message' => 'Certificado validado com sucesso.',
                'data'    => [
                    'certificado_info' => $certificadoInfo,
                    'name'             => $razaoSocial,
                    'address'          => $endereco,
                    'document_number'  => $cnpj,
                    'expiration_date'  => $expirationDate,
                    'process_output'   => $processDados->getOutput(),
                ],
            ];

        } catch (Exception $e) {
            return [
                'success' => false,
                'message' => $e->getMessage(),
                'data'    => null,
            ];
        }
    }

    public function convertPEM(array $data): array
    {
        $certificadoPfx      = storage_path('app/public/' . $data['certified']);
        $certificadoPassword = $data['certified_password'];
        $certificadoPemName  = 'certificate/' . pathinfo($data['certified'], PATHINFO_FILENAME) . '_KEY.pem';
        $certificadoPem      = storage_path('app/public/' . $certificadoPemName);

        $comando = "openssl pkcs12 -in $certificadoPfx -out $certificadoPem -nodes -password pass:$certificadoPassword";

        try {
            $result = \Illuminate\Support\Facades\Process::run($comando);

            if ($result->failed()) {
                throw new \Exception($result->errorOutput());
            }

            return [
                'success' => true,
                'message' => 'Certificado convertido com sucesso.',
                'file'    => $certificadoPemName,
            ];
        } catch (\Exception $e) {
            return [
                'success' => false,
                'message' => 'Erro ao processar certificado' . $e->getMessage(),
                'file'    => null,
            ];
        }
    }

    public function convertPrivate(array $data): array
    {
        $certificadoPfx      = storage_path('app/public/' . $data['certified_pem']);
        $certificadoPemName  = 'certificate/' . pathinfo($data['certified'], PATHINFO_FILENAME) . '_PRIVATE.pem';
        $certificadoPem      = storage_path('app/public/' . $certificadoPemName);

        $comando = "openssl pkey -in $certificadoPfx -out $certificadoPem";

        try {
            $result = \Illuminate\Support\Facades\Process::run($comando);

            if ($result->failed()) {
                throw new \Exception($result->errorOutput());
            }

            return [
                'success' => true,
                'message' => 'Certificado convertido com sucesso.',
                'file'    => $certificadoPemName,
            ];
        } catch (\Exception $e) {
            return [
                'success' => false,
                'message' => 'Erro ao processar certificado' . $e->getMessage(),
                'file'    => null,
            ];
        }
    }
}
