<?php

namespace App\Services;

use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class Whaticket
{
    private function getApiWhaticketUrl()
    {
        return config('app.api_whaticket_url');
    }

    private function getApiWhaticketToken()
    {
        return config('app.api_whaticket_token');
    }

    public function sendMessage($numberTo, $message)
    {

        $apiUrl   = $this->getApiWhaticketUrl();
        $apiToken = $this->getApiWhaticketToken();

        if (empty($apiUrl) || empty($apiToken)) {
            Log::error('Whaticket API URL or Token is not configured.');

            return false;
        }

        $body = [
            'number' => $numberTo,
            'body'   => $message,
        ];

        return $this->json($apiUrl . 'api/messages/send', $body);
    }

    private function json($url, array $body)
    {
        $response = Http::withHeaders([
            'Authorization' => 'Bearer ' . $this->getApiWhaticketToken(),
            'Content-Type'  => 'application/json',
        ])->post($url, $body);

        if ($response->getStatusCode() !== 200) {
            Log::error('Whaticket Error response: ' . $response->getBody()->getContents());
            $errorJson = json_decode($response->getBody()->getContents(), true);
        }

        return $response->getBody()->getContents() === '';
    }

}
