<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class () extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::disableForeignKeyConstraints();

        Schema::create('users', function (Blueprint $table) {
            $table->id();
            $table->uuid('uuid');

            $table->string('name');
            $table->string('nickname')->nullable()->comment('Nome');
            $table->string('username', 50)->unique()->comment('Login');

            $table->string('email')->unique();
            $table->timestamp('email_verified_at')->nullable();
            $table->string('password');
            $table->string('avatar_url')->nullable();
            $table->string('avatar')->nullable()->comment('imagem');

            $table->foreignId('group_id')->nullable()->constrained()->comment('Grupo');

            $table->integer('access_number')->unsigned()->default(0)->comment('Quantidade de acessos');
            $table->dateTime('last_login_at')->nullable()->comment('Ultimo acessos');
            $table->date('access_until_day')->nullable()->comment('Acesso ate o dia');

            $table->rememberToken();
            $table->boolean('is_active')->default(true);
            $table->timestamps();
            $table->softDeletes();
        });

        Schema::enableForeignKeyConstraints();
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('users');
    }
};
