<?php

use App\Enums\SpedNfe\CrtEnum;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('companies', function (Blueprint $table) {
            $table->id();
            $table->uuid();
            $table->foreignId('company_id')->nullable()->constrained()->comment('Matriz');

            $table->string('name', 100)->comment('Razão Social');
            $table->string('fantasy_name', 100)->comment('Nome');
            $table->string('initial', 15)->nullable()->comment('Iniciais');
            $table->string('slug')->unique();

            $table->string('document_number', 14)->unique();
            $table->string('state_registration')->nullable()->comment('Inscrição Estadual');
            $table->string('municipal_registration')->nullable()->comment('Inscrição Municipal');

            $table->string('zip_code', 8)->nullable()->comment('CEP');
            $table->string('address')->nullable()->comment('Endereço');
            $table->string('address_number')->nullable()->comment('Número');
            $table->string('neighborhood')->nullable()->comment('Bairro');
            $table->string('address_complement')->nullable()->comment('Complemento');
            $table->foreignId('city_id')->constrained()->comment('Cidade');

            $table->string('mobile_number', 15)->nullable()->comment('Celular');
            $table->string('phone_number', 15)->nullable()->comment('Telefone');
            $table->string('email')->nullable()->comment('E-mail');
            $table->string('website')->nullable()->comment('Site');


            $table->string('responsible_name')->nullable()->comment('Nome do responsável');
            $table->string('responsible_function')->nullable()->comment('Função do responsável');
            $table->text('observation')->nullable()->comment('Observações');

            $table->string('certified')->nullable()->comment('Certificado');
            $table->string('certified_pem')->nullable()->comment('Certificado');
            $table->string('certified_private')->nullable()->comment('Certificado');
            $table->string('certified_password',50)->nullable()->comment('Senha do certificado');
            $table->dateTime('certified_expiration_date')->nullable()->comment('Data de vencimento do certificado');

            $table->boolean('is_active')->default(1)->index()->comment('Status');

            $table->timestamps();
            $table->softDeletes()->index();
        });

        Schema::create('company_user', function (Blueprint $table) {
            $table->id();
            $table->foreignId('company_id')->constrained();
            $table->foreignId('user_id')->constrained();
            $table->timestamps();
            $table->softDeletes()->index();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('companies');
        Schema::dropIfExists('company_user');
    }
};
