<?php

use App\Enums\RegistryStatusEnum;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('registries', function (Blueprint $table) {
            $table->id();
            $table->uuid();
            $table->foreignId('company_id')->nullable()->constrained();
            $table->string('document_number', 14)->unique();
            $table->string('identity_document', 50)->nullable()->comment('Documento de identidade');
            $table->string('state_registration', 30)->nullable()->comment('Inscrição estadual');
            $table->string('municipal_registration', 30)->nullable()->comment('Inscrição municipal');
            $table->string('suframa', 30)->nullable()->comment('Suframa');
            $table->string('antt', 30)->nullable()->comment('ANTT');
            $table->integer('contribuinte_icms')->nullable()->index()->comment('1-sim,2-não')->comment('Contribuinte ICMS');
            $table->string('responsible_name', 200)->nullable()->comment('Nome do responsavel');
            $table->string('responsible_fantasy_name', 150)->nullable()->comment('Como é conhecido o responsavel');
            $table->string('responsible_function', 50)->nullable()->comment('Função do responsvel');
            $table->string('name')->comment('Nome');
            $table->string('fantasy_name')->nullable()->comment('Nome Fantasia');
            $table->date('birthday')->nullable()->comment('Data de Nascimento');
            $table->string('zip_code', 10)->nullable()->comment('CEP');
            $table->string('address')->nullable()->comment('Endereço');
            $table->string('address_number')->nullable()->comment('Número');
            $table->string('neighborhood')->nullable()->comment('Bairro');
            $table->string('address_complement')->nullable()->comment('Complemento');
            $table->string('address_reference')->nullable()->comment('Referencia');
            $table->foreignId('city_id')->nullable()->constrained()->comment('Cidade');
            $table->string('mobile_number', 15)->comment('Numero');
            $table->string('phone_number', 15)->comment('Numero');
            $table->string('email')->nullable()->comment('E-mail');
            $table->string('email_nfe')->nullable()->comment('E-mail NF-e');
            $table->string('website')->nullable()->comment('Site');
            $table->text('observation')->nullable()->comment('Observações');
            $table->string('avatar_url')->nullable()->comment('imagem');
            $table->boolean('is_active')->default(1)->index()->comment('Status');
            $table->timestamps();
            $table->softDeletes()->index();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('registries');
    }
};
